{% load i18n widget_tweaks %}

<div class="row">
  <div class="col-md-3">
    {% if field.errors %}
      <div class="alert alert-danger" role="alert">
        <span class="glyphicon glyphicon-exclamation-sign"
              aria-hidden="true">
        </span>
        <span class="sr-only">{% trans "Error:" %}</span>

        {% for error in field.errors %}
          {{ error }}<br/>
        {% endfor %}
      </div>
    {% endif %}
  </div>
  <div class="col-md-6">
    <div class="form-group form-tooltip"
         data-toggle="tooltip"
         data-placement="top"
         title="{{ field.help_text }}">

      {% if field.field.required %}
        <span class="required-field">*</span>
      {% endif %}

      {{ field.label_tag }}
      {% render_field field class+="form-control" %}
    </div>
  </div>
</div>
