/* TOC */

.toctitle {
  text-align: center;
  width: 100%;
  font-weight: bolder;
}

.toc {
  border: 1px solid #aaa;
  background-color: #f9f9f9;
  display: table;
  padding: 7px;
  padding-right: 20px;
  margin-bottom: 10px;
}

.toc ol ol {
  padding-left: 15px;
}

.article-delete-warning {
  margin-bottom: 5px !important;
}
